import { Algorithm, JWTConstructorOptions, JWTHeader as IJWTHeader, JWTHeaderConstructorOptions, JWTJSONForm, JWTPayload as IJWTPayload, JWTPayloadConstructorOptions, JWTPayloadJSONForm, JWTPayloadOptions, JWTPayloadOptionsDefault, Key } from "../types";
export declare class JWTToken<O extends JWTPayloadOptions = JWTPayloadOptionsDefault, P extends {} | undefined = undefined, H extends {} | undefined = undefined, SIG extends boolean = true> {
    readonly header: JWTHeader<H>;
    readonly payload: JWTPayload<P, O>;
    readonly signature: SIG extends true ? string : undefined;
    constructor(options: JWTConstructorOptions<O, P, H, SIG>);
    toJSON(): JWTJSONForm<O, P, H, SIG>;
    toString(): string;
    getSignableString(): string;
    isSigned(): SIG;
    isNotExpired(reseve?: number, at?: Date): boolean;
    isAfterNotBefore(at?: Date): boolean;
    isTimeValid(reserve?: number, at?: Date): boolean;
    isCorrectAudience(audience: string): boolean;
    isIssuedAfter(at?: Date): boolean | undefined;
    isFromTrustedIssuer(issuerIsTrusted: ((issuer: string) => Promise<boolean>) | string | string[]): Promise<boolean>;
    protected getSignature(key: Key): Promise<string>;
    sign(key: Key): Promise<JWTToken<O, P, H, true>>;
    verifySignature(key: Key): Promise<boolean>;
    verify(key: Key, reserve?: number, at?: Date, issuerIsTrusted?: ((issuer: string) => Promise<boolean>) | string | string[], audience?: string): Promise<boolean>;
    static fromJSON<O extends JWTPayloadOptions = JWTPayloadOptionsDefault, P extends {} | undefined = undefined, H extends {} | undefined = undefined, SIG extends boolean = true>(json: JWTJSONForm<O, P, H, SIG>): JWTToken<O, P, H, SIG>;
    static fromString<O extends JWTPayloadOptions = JWTPayloadOptionsDefault, P extends {} | undefined = undefined, H extends {} | undefined = undefined, SIG extends boolean = true>(token: string): JWTToken<O, P, H, SIG>;
}
export declare class JWTHeader<A extends {} | undefined = undefined> implements IJWTHeader {
    readonly alg: Algorithm;
    readonly typ: "JWT";
    readonly additional: A extends {} ? A : {};
    constructor(options: JWTHeaderConstructorOptions<A>);
    toJSON(): A extends {} ? IJWTHeader & A : IJWTHeader;
    toString(): string;
    static fromJSON<A extends {} | undefined = undefined>(headers: A extends {} ? IJWTHeader & A : IJWTHeader): JWTHeader<A>;
    static fromString<A extends {} | undefined = undefined>(header: string): JWTHeader<A>;
}
export declare class JWTPayload<A extends {} | undefined = undefined, O extends JWTPayloadOptions = JWTPayloadOptionsDefault> implements IJWTPayload<O> {
    readonly iss: O["iss"];
    readonly sub: O["sub"];
    readonly aud: O["aud"][];
    readonly exp: Date;
    readonly nbf: O["nbf"];
    readonly iat: O["iat"];
    readonly jti: O["jti"];
    readonly additional: A extends {} ? A : {};
    constructor(options: JWTPayloadConstructorOptions<A, O>);
    toJSON(): A extends {} ? JWTPayloadJSONForm<O> & A : JWTPayloadJSONForm<O>;
    toString(): string;
    static fromJSON<A extends {} | undefined = undefined, O extends JWTPayloadOptions = JWTPayloadOptionsDefault>(payload: A extends {} ? JWTPayloadJSONForm<O> & A : JWTPayloadJSONForm<O>): JWTPayload<A, O>;
    static fromString<A extends {} | undefined = undefined, O extends JWTPayloadOptions = JWTPayloadOptionsDefault>(payload: string): JWTPayload<A, O>;
}
//# sourceMappingURL=jwt.d.ts.map